@@ -22,6 +22,8 @@ LIBNAMES = (
     "libtidy-0.99.so.0.0.0",
     # HTML tidy
     "libtidy.so.5",
+    # Linux, HTML tidy v5.8
+    "libtidy.so.58",
     # Debian changed soname
     "libtidy.so.5deb1",
     # Windows?
@@ -45,6 +47,11 @@ class Loader:
             (os.path.dirname(__file__), os.pathsep, os.environ["PATH"])
         )
 
+        # Add full path to a library
+        lib_path = os.environ.get("TIDY_LIBRARY_FULL_PATH")
+        if lib_path:
+            self.libnames = (lib_path,) + self.libnames
+
         # Try loading library
         for libname in self.libnames:
             try:
@@ -60,6 +67,7 @@ class Loader:
         # Adjust some types
         if self.lib is not None:
             self.Create.restype = ctypes.POINTER(ctypes.c_void_p)
+            self.LibraryVersion.restype = ctypes.c_char_p
 
     def __getattr__(self, name):
         return getattr(self.lib, "tidy%s" % name)
@@ -317,3 +325,7 @@ class DocumentFactory(FactoryDict):
 docfactory = DocumentFactory()
 parse = docfactory.parse
 parseString = docfactory.parseString
+
+
+def getTidyVersion():
+    return _tidy.lib.tidyLibraryVersion().decode()
